pub struct Span<F = FileId> {
pub root: F,
pub start: usize,
pub end: usize,
}Fields
root: Fstart: usizeend: usizeImplementations
Sourceimpl Span<Root>
impl Span<Root>
pub fn of_token(syntax_token: &SyntaxToken) -> Self
pub fn of_node(syntax_node: &SyntaxNode) -> Self
pub fn of_lustre_str(string_node: &Str) -> Self
Sourcepub fn after(self) -> Self
pub fn after(self) -> Self
Returns a 0-long span located just after another span, useful for reported missing syntax
Sourcepub fn extend(&mut self, other: impl IntoIterator<Item = Self>)
pub fn extend(&mut self, other: impl IntoIterator<Item = Self>)
Extends the span using other spans, effectively keeping the lowest start bound and the
highest end bound